@@ -200,6 +200,19 @@ calculate_overlay_geometry(PanelWidget *panel, GtkWidget *parent,
 
 	translate_to(GTK_WIDGET(panel), parent, x, y);
 
+	/* when not shown, things are somewhat weird, and we try to put the
+	 * window completely off as it can't be clickable anyway */
+	/* XXX: These window thingies should really be unmapped in hidden
+	 * case, or something like that, this is ugly, but who gives a fuck,
+	 * this is all going to be rewritten soon (famous last words?) */
+	if(IS_BASEP_WIDGET(parent) &&
+	   BASEP_WIDGET(parent)->state != BASEP_SHOWN &&
+	   BASEP_WIDGET(parent)->state != BASEP_AUTO_HIDDEN) {
+		*x = parent->requisition.width + 1;
+		*y = parent->requisition.height + 1;
+		return;
+	}
+
 	if(panel->orient == PANEL_HORIZONTAL) {
 		*y = 0;
 		/* we use the requisition, since allocation might have not
@@ -568,24 +581,14 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 	pwidget = widget->parent;
 	
 	if(tiles_enabled[button->tile]) {
+		GdkPixbuf *pb = NULL;
 		if(button->pressed && button->in_button) {
-			GdkPixbuf *pb;
 			if(!global_config.saturate_when_over ||
 			   !button->in_button) {
 				pb = tiles.tiles_down[button->tile];
 			} else {
 				pb = tiles.tiles_down_hc[button->tile];
 			}
-			if(pb) {
-				double affine[6];
-				make_scale_affine(affine,
-						  gdk_pixbuf_get_width(pb),
-						  gdk_pixbuf_get_height(pb),
-						  size, NULL, NULL);
-				transform_pixbuf(rgb, 0, 0, size, size,
-						 rowstride, pb, affine,
-						 ART_FILTER_NEAREST, NULL);
-			}
 		} else if (!global_config.tile_when_over ||
 			   button->in_button) {
 			GdkPixbuf *pb;
@@ -595,45 +598,65 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 			} else {
 				pb = tiles.tiles_up_hc[button->tile];
 			}
-			if(pb) {
-				double affine[6];
-				make_scale_affine(affine,
-						  gdk_pixbuf_get_width(pb),
-						  gdk_pixbuf_get_height(pb),
-						  size, NULL, NULL);
-				transform_pixbuf(rgb, 0, 0, size, size,
-						 rowstride, pb, affine,
-						 ART_FILTER_NEAREST, NULL);
-			}
+		}
+
+		if(pb != NULL) {
+			GdkPixbuf *scaled_pb;
+			double affine[6];
+			GdkInterpType interp;
+
+			if (global_config.fast_button_scaling)
+				interp = GDK_INTERP_NEAREST;
+			else
+				interp = GDK_INTERP_HYPER;
+
+			scaled_pb = scale_pixbuf_to_square (pb, size,
+							    NULL, NULL,
+							    interp);
+
+			art_affine_identity (affine);
+
+			transform_pixbuf(rgb, 0, 0, size, size,
+					 rowstride, scaled_pb, affine,
+					 ART_FILTER_NEAREST, NULL);
+
+			gdk_pixbuf_unref (scaled_pb);
 		}
 	}
 
 	if (pixmaps_enabled[button->tile]) {
-		GdkPixbuf *pb;
+		GdkPixbuf *pb = NULL;
 		if(!global_config.saturate_when_over || !button->in_button) {
 			pb = button->pixbuf;
 		} else {
 			pb = button->pixbuf_hc;
 		}
-		if(pb) {
+		if(pb != NULL) {
 			double affine[6];
-			double transl[6];
-			int w,h;
-			make_scale_affine(affine,
-					  gdk_pixbuf_get_width(pb),
-					  gdk_pixbuf_get_height(pb),
-					  size, &w, &h);
-			art_affine_translate(transl,
+			int w, h;
+			GdkPixbuf *scaled_pb;
+			GdkInterpType interp;
+
+			if (global_config.fast_button_scaling)
+				interp = GDK_INTERP_NEAREST;
+			else
+				interp = GDK_INTERP_HYPER;
+
+			scaled_pb = scale_pixbuf_to_square (pb, size, &w, &h,
+							    interp);
+
+			art_affine_translate(affine,
 					     -border+off + (size-w)/2,
 					     -border+off + (size-h)/2);
-			art_affine_multiply(affine, affine, transl);
 
 			transform_pixbuf((rgb+border*rowstride+border*3),
 				         0, 0,
 				         size-2*border, size-2*border,
 				         rowstride,
-				         pb,
+				         scaled_pb,
 				         affine, ART_FILTER_NEAREST, NULL);
+
+			gdk_pixbuf_unref (scaled_pb);
 		}
 	}
 }
@@ -1093,7 +1116,6 @@ button_widget_load_tile(int tile, char *tile_up, char *tile_down,
 			int border, int depth)
 {
 	GdkPixbuf *pb;
-	GList *list;
 
 	g_return_if_fail(tile >= 0);
 	g_return_if_fail(tile < LAST_TILE);
@@ -1121,17 +1143,7 @@ button_widget_load_tile(int tile, char *tile_up, char *tile_down,
 	tile_border[tile] = border;
 	tile_depth[tile] = depth;
 
-	for(list = buttons;list!=NULL;list=g_list_next(list)) {
-		ButtonWidget *button = list->data;
-		if(button->tile == tile) {
-			if(button->cache)
-				gdk_pixmap_unref(button->cache);
-			button->cache = NULL;
-			setup_no_alpha(button);
-			panel_widget_draw_icon(PANEL_WIDGET(GTK_WIDGET(button)->parent),
-					       button);
-		}
-	}
+	button_widget_redo_all ();
 }
 
 void
@@ -1146,20 +1158,25 @@ button_widget_set_flags(int tile,
 	if(tiles_enabled[tile] != _tiles_enabled ||
 	   pixmaps_enabled[tile] != _pixmaps_enabled ||
 	   always_text[tile] != _always_text) {
-		GList *list;
-
 		tiles_enabled[tile] = _tiles_enabled;
 		pixmaps_enabled[tile] = _pixmaps_enabled;
 		always_text[tile] = _always_text;
 
-		for(list = buttons;list!=NULL;list=g_list_next(list)) {
-			ButtonWidget *button = list->data;
-			if(button->cache)
-				gdk_pixmap_unref(button->cache);
-			button->cache = NULL;
-			setup_no_alpha(button);
-			panel_widget_draw_icon(PANEL_WIDGET(GTK_WIDGET(list->data)->parent),
-					       button);
-		}
+		button_widget_redo_all ();
+	}
+}
+
+void
+button_widget_redo_all (void)
+{
+	GList *list;
+
+	for(list = buttons; list != NULL; list = list->next) {
+		ButtonWidget *button = list->data;
+		if(button->cache != NULL)
+			gdk_pixmap_unref(button->cache);
+		button->cache = NULL;
+		setup_no_alpha(button);
+		gtk_widget_queue_draw (GTK_WIDGET (button));
 	}
 }
