@@ -5,26 +5,26 @@
  *           George Lebl
  */
 
-#ifndef __DRAWER_WIDGET_H__
-#define __DRAWER_WIDGET_H__
+#ifndef DRAWER_WIDGET_H
+#define DRAWER_WIDGET_H
 
 #include "basep-widget.h"
 #include "drawer.h"
 
 BEGIN_GNOME_DECLS
 
-#define DRAWER_POS_TYPE            (drawer_pos_get_type ())
-#define DRAWER_POS(o)              (GTK_CHECK_CAST ((o), DRAWER_POS_TYPE, DrawerPos))
+#define TYPE_DRAWER_POS            (drawer_pos_get_type ())
+#define DRAWER_POS(o)              (GTK_CHECK_CAST ((o), TYPE_DRAWER_POS, DrawerPos))
 #define DRAWER_POS_CLASS(k)        (GTK_CHECK_CLASS_CAST ((k), DRAWER_POS_TYPE, DrawerPosClass))
-#define IS_DRAWER_POS(o)          (GTK_CHECK_TYPE ((o), DRAWER_POS_TYPE))
-#define IS_DRAWER_POS_CLASS(k)    (GTK_CHECK_CLASS_TYPE ((k), DRAWER_POS_TYPE))
+#define IS_DRAWER_POS(o)           (GTK_CHECK_TYPE ((o), TYPE_DRAWER_POS))
+#define IS_DRAWER_POS_CLASS(k)     (GTK_CHECK_CLASS_TYPE ((k), TYPE_DRAWER_POS))
 
-#define DRAWER_WIDGET_TYPE         (BASEP_WIDGET_TYPE)
+#define TYPE_DRAWER_WIDGET         (TYPE_BASEP_WIDGET)
 #define DRAWER_WIDGET(o)           (BASEP_WIDGET(o))
 #define DRAWER_WIDGET_CLASS(k)     (BASEP_WIDGET_CLASS(k))
 #define IS_DRAWER_WIDGET(o)        (IS_BASEP_WIDGET(o) && IS_DRAWER_POS(BASEP_WIDGET(o)->pos))
 /* this is not reliable */
-#define IS_DRAWER_WIDGET_CLASS(k) (IS_BASEP_WIDGET_CLASS(k))
+#define IS_DRAWER_WIDGET_CLASS(k)  (IS_BASEP_WIDGET_CLASS(k))
 
 typedef BasePWidget            DrawerWidget;
 typedef BasePWidgetClass       DrawerWidgetClass;
@@ -49,7 +49,7 @@ struct _DrawerPosClass {
 #endif
 };
 
-GtkType drawer_pos_get_type (void);
+GtkType drawer_pos_get_type (void) G_GNUC_CONST;
 GtkWidget *drawer_widget_new (PanelOrientType orient,
 			      BasePMode mode,
 			      BasePState state,
