@@ -48,6 +48,10 @@ char *kde_menudir = NULL;
 char *kde_icondir = NULL;
 char *kde_mini_icondir = NULL;
 
+char *merge_merge_dir = NULL;
+int merge_main_dir_len = 0;
+char *merge_main_dir = NULL;
+
 static int
 menu_age_timeout(gpointer data)
 {
@@ -143,6 +147,31 @@ find_kde_directory(void)
 	kde_mini_icondir = g_strdup(KDE_MINI_ICONDIR);
 }
 
+static void
+setup_merge_directory(void)
+{
+	int len;
+
+	merge_main_dir = gnome_datadir_file("gnome/apps/");
+	merge_main_dir_len = merge_main_dir != NULL ? strlen (merge_main_dir) : 0;
+	merge_merge_dir = gnome_config_get_string("/panel/Merge/Directory=/etc/X11/applnk/");
+
+	if (merge_merge_dir == NULL ||
+	    merge_merge_dir[0] == '\0' ||
+	    ! g_file_test(merge_merge_dir, G_FILE_TEST_ISDIR)) {
+		g_free(merge_merge_dir);
+		merge_merge_dir = NULL;
+		return;
+	}
+
+	len = strlen(merge_merge_dir);
+	if (merge_merge_dir[len-1] != '/') {
+		char *tmp = g_strconcat(merge_merge_dir, "/", NULL);
+		g_free(merge_merge_dir);
+		merge_merge_dir = tmp;
+	}
+}
+
 static void
 setup_visuals (void)
 {
@@ -196,6 +225,8 @@ main(int argc, char **argv)
 	}
 	}
 
+	setup_merge_directory();
+
 	find_kde_directory();
 
 	client = gnome_master_client ();
@@ -237,7 +268,8 @@ main(int argc, char **argv)
 	/* read, convert and remove old config */
 	convert_old_config();
 
-	/*set the globals*/
+	/* set the globals, it is important this is before
+	 * init_user_applets */
 	load_up_globals();
 	/* this is so the capplet gets the right defaults */
 	write_global_config();
@@ -261,9 +293,9 @@ main(int argc, char **argv)
 
 	/*attempt to sync the config every 10 seconds, only if a change was
 	  indicated though*/
-	config_sync_timeout = gtk_timeout_add(10*1000,try_config_sync,NULL);
+	config_sync_timeout = gtk_timeout_add(10*1000, try_config_sync, NULL);
 
-	gtk_timeout_add(10*1000,menu_age_timeout,NULL);
+	gtk_timeout_add(10*1000, menu_age_timeout, NULL);
 	
 	/*load these as the last thing to prevent some races any races from
 	  starting multiple goad_id's at once are libgnorba's problem*/
@@ -271,7 +303,6 @@ main(int argc, char **argv)
 
 	status_applet_create_offscreen();
 
-	/* I use the glue code to avoid making this a C++ file */
 	gtk_main ();
 
 	return 0;
