@@ -89,7 +89,10 @@ apply_global_config(void)
 	static int autohide_size_old = -1;
 	static int menu_flags_old = -1;
 	static int old_use_large_icons = -1;
+	static int old_merge_menus = -1;
+	static int old_fast_button_scaling = -1;
 	GSList *li;
+
 	panel_widget_change_global(global_config.explicit_hide_step_size,
 				   global_config.auto_hide_step_size,
 				   global_config.drawer_step_size,
@@ -103,22 +106,28 @@ apply_global_config(void)
 		gtk_tooltips_enable(panel_tooltips);
 	else
 		gtk_tooltips_disable(panel_tooltips);
+	/* not incredibly efficent way to do this, we just make
+	 * sure that all directories are reread */
+	if(old_merge_menus != global_config.merge_menus) {
+		fr_force_reread();
+	}
 	/*if we changed dot_buttons/small_icons mark all menus as dirty
 	  for rereading, hopefullly the user doesn't do this too often
 	  so that he doesn't have to reread his menus all the time:)*/
 	if(dot_buttons_old != global_config.show_dot_buttons ||
-	   old_use_large_icons != global_config.use_large_icons) {
+	   old_use_large_icons != global_config.use_large_icons ||
+	   old_merge_menus != global_config.merge_menus) {
 		GSList *li;
-		for(li=applets;li!=NULL;li=g_slist_next(li)) {
+		for(li = applets; li != NULL; li = g_slist_next(li)) {
 			AppletInfo *info = li->data;
-			if(info->menu) {
+			if(info->menu != NULL) {
 				gtk_widget_unref(info->menu);
 				info->menu = NULL;
 				info->menu_age = 0;
 			}
 			if(info->type == APPLET_MENU) {
 				Menu *menu = info->data;
-				if(menu->menu) {
+				if(menu->menu != NULL) {
 					gtk_widget_unref(menu->menu);
 					menu->menu = NULL;
 					menu->age = 0;
@@ -127,17 +136,37 @@ apply_global_config(void)
 		}
 		for(li = panel_list; li != NULL; li = g_slist_next(li)) {
 			PanelData *pd = li->data;
-			if(pd->menu) {
+			if(pd->menu != NULL) {
 				gtk_widget_unref(pd->menu);
 				pd->menu = NULL;
 				pd->menu_age = 0;
 			}
 		}
+		foobar_widget_force_menu_remake();
 	}
 	dot_buttons_old = global_config.show_dot_buttons;
 	old_use_large_icons = global_config.use_large_icons;
+	old_merge_menus = global_config.merge_menus;
 	send_tooltips_state(global_config.tooltips_enabled);
 
+	/* if we changed global menu flags, cmark all main menus that use
+	 * the global setting as dirty */
+	if(menu_flags_old != global_config.menu_flags) {
+		GSList *li;
+		for(li = applets; li != NULL; li = g_slist_next(li)) {
+			AppletInfo *info = li->data;
+			if(info->type == APPLET_MENU) {
+				Menu *menu = info->data;
+				if(menu->menu != NULL &&
+				   menu->global_main) {
+					gtk_widget_unref(menu->menu);
+					menu->menu = NULL;
+					menu->age = 0;
+				}
+			}
+		}
+	}
+
 	if(keep_bottom_old == -1 ||
 	   keep_bottom_old != global_config.keep_bottom) {
 		for(li = panel_list; li != NULL; li = g_slist_next(li)) {
@@ -152,14 +181,19 @@ apply_global_config(void)
 	}
 	keep_bottom_old = global_config.keep_bottom;
 
-	for(i=0;i<LAST_TILE;i++) {
+	for(i = 0; i < LAST_TILE; i++) {
 		button_widget_set_flags(i, global_config.tiles_enabled[i],
-					1,0);
+					1, 0);
 		button_widget_load_tile(i, global_config.tile_up[i],
 					global_config.tile_down[i],
 					global_config.tile_border[i],
 					global_config.tile_depth[i]);
-	}	
+	}
+
+	if (old_fast_button_scaling != global_config.fast_button_scaling) {
+		button_widget_redo_all ();
+	}
+	old_fast_button_scaling = global_config.fast_button_scaling;
 
 	for(li = panel_list; li != NULL; li = g_slist_next(li)) {
 		PanelData *pd = li->data;
@@ -426,7 +460,13 @@ save_applet_configuration(AppletInfo *info)
 						menu->path);
 			gnome_config_set_int("main_menu_flags",
 					     menu->main_menu_flags);
-			gnome_config_set_bool("old_style_main",FALSE);
+			gnome_config_set_bool("global_main",
+					      menu->global_main);
+			gnome_config_set_bool("old_style_main", FALSE);
+			gnome_config_set_bool("custom_icon",
+					      menu->custom_icon);
+			gnome_config_set_string("custom_icon_file",
+						menu->custom_icon_file);
 			break;
 		}
 	case APPLET_LAUNCHER:
@@ -786,19 +826,21 @@ load_default_applets1(PanelWidget *panel)
 	char *p;
 	int sz;
 
-	if(gdk_screen_width()<800)
+	if(gdk_screen_width() <= 320)
+		sz = SIZE_ULTRA_TINY;
+	else if(gdk_screen_width() < 800)
 		sz = SIZE_TINY;
-	else if(gdk_screen_width()<1024)
+	else if(gdk_screen_width() < 1024)
 		sz = SIZE_SMALL;
 	else
 		sz = SIZE_STANDARD;
 
 	/* load up the foot menu */
-	load_menu_applet(NULL, get_default_menu_flags (), 
-			 panel, 0, TRUE);
+	load_menu_applet(NULL, get_default_menu_flags (),
+			 TRUE, FALSE, NULL, panel, 0, TRUE);
 
 	/*load up some buttons, but only if screen larger then 639*/
-	if(gdk_screen_width()>=640) {
+	if(gdk_screen_width() >= 640) {
 		load_logout_applet(panel, sz, TRUE);
 		load_lock_applet(panel, sz*2, TRUE);
 
@@ -871,6 +913,7 @@ init_user_applets(void)
 {
 	GString *buf;
 	int count, num;	
+	DistributionType distribution = get_distribution_type();
 
 	count = gnome_config_get_int(PANEL_CONFIG_PATH
 				     "panel/Config/applet_count=0");
@@ -954,9 +997,19 @@ init_user_applets(void)
 			char *s;
 			int type =
 				gnome_config_get_int("main_menu_type=-1");
+			/* this defaults to false, because we want old menus to
+			 * work in the old style */
+			gboolean global_main_was_default;
+			gboolean global_main =
+				gnome_config_get_bool_with_default("global_main=false",
+								   &global_main_was_default);
 			int flags;
 			gboolean old_style = 
 				gnome_config_get_bool("old_style_main=true");
+			gboolean custom_icon = 
+				gnome_config_get_bool ("custom_icon=false");
+			char *custom_icon_file =
+				gnome_config_get_string ("custom_icon_file=");
 
 			s = g_strdup_printf("main_menu_flags=%d",
 					    (int)(MAIN_MENU_SYSTEM_SUB |
@@ -966,8 +1019,15 @@ init_user_applets(void)
 						  MAIN_MENU_DESKTOP));
 			flags = gnome_config_get_int(s);
 			g_free(s);
+			
+			/* Hack to try to do the right conversion while trying
+			 * to turn on the feature on as many setups as possible */
+			if (global_main_was_default &&
+			    flags == global_config.menu_flags) {
+				global_main = TRUE;
+			}
 
-			if(type>=0) {
+			if(type >= 0) {
 				flags = 0;
 				if(type == X_MAIN_MENU_BOTH) {
 					flags |= MAIN_MENU_SYSTEM|MAIN_MENU_USER;
@@ -978,15 +1038,12 @@ init_user_applets(void)
 					flags |= MAIN_MENU_SYSTEM_SUB|
 						MAIN_MENU_USER;
 				}
-				/*guess redhat menus*/
-				if(g_file_exists("/etc/X11/wmconfig"))
-					flags |= MAIN_MENU_REDHAT_SUB;
+				/*guess distribution menus*/
+				if(distribution != DISTRIBUTION_UNKNOWN)
+					flags |= MAIN_MENU_DISTRIBUTION_SUB;
 				/*guess KDE menus */
 				if(g_file_exists(kde_menudir))
 					flags |= MAIN_MENU_KDE_SUB;
-				/*guess debian menus*/
-				if (g_file_exists(DEBIAN_MENUDIR))
-					flags |= MAIN_MENU_DEBIAN_SUB;
 			}
 			if(old_style) {
 				/*this is needed to make panel properly
@@ -997,12 +1054,14 @@ init_user_applets(void)
 				if(flags&MAIN_MENU_USER &&
 				   flags&MAIN_MENU_USER_SUB)
 					flags &=~ MAIN_MENU_USER;
-				if(flags&MAIN_MENU_REDHAT &&
-				   flags&MAIN_MENU_REDHAT_SUB)
-					flags &=~ MAIN_MENU_REDHAT;
-				if(flags&MAIN_MENU_DEBIAN &&
-				   flags&MAIN_MENU_DEBIAN_SUB)
-					flags &=~ MAIN_MENU_DEBIAN;
+				if(flags&MAIN_MENU_DISTRIBUTION &&
+				   flags&MAIN_MENU_DISTRIBUTION_SUB)
+					flags &=~ MAIN_MENU_DISTRIBUTION;
+				/*keep this for compatibility with older
+				  config files */
+				if(flags&MAIN_MENU_OBSOLETE_DEBIAN &&
+				   flags&MAIN_MENU_OBSOLETE_DEBIAN_SUB)
+					flags &=~ MAIN_MENU_DISTRIBUTION;
 				if(flags&MAIN_MENU_KDE &&
 				   flags&MAIN_MENU_KDE_SUB)
 					flags &=~ MAIN_MENU_KDE;
@@ -1011,8 +1070,17 @@ init_user_applets(void)
 					MAIN_MENU_DESKTOP;
 			}
 
-			load_menu_applet(params, flags, panel, pos, TRUE);
-			g_free(params);
+			if (old_style)
+				load_menu_applet(params, flags, FALSE,
+						 custom_icon, custom_icon_file,
+						 panel, pos, TRUE);
+			else
+				load_menu_applet(params, flags, global_main,
+						 custom_icon, custom_icon_file,
+						 panel, pos, TRUE);
+
+			g_free (custom_icon_file);
+			g_free (params);
 		} else if(strcmp(applet_name, DRAWER_ID) == 0) {
 			int mypanel = gnome_config_get_int("parameters=-1");
 			char *pixmap = gnome_config_get_string("pixmap=");
@@ -1034,6 +1102,7 @@ init_user_panels(void)
 {
 	GString *buf;
 	int count, num;	
+	char *s;
 	GtkWidget *panel=NULL;
 
 	count = gnome_config_get_int(PANEL_CONFIG_PATH
@@ -1043,14 +1112,17 @@ init_user_panels(void)
 	  it is required to have at least one panel for this all
 	  to work, so this is the way we find out if there was no
 	  config from last time*/
-	if(count<=0)  {
+	if(count <= 0)  {
 		int sz;
 		gboolean hidebutton_pixmaps;
 
-		if(gdk_screen_width()<800) {
+		if(gdk_screen_width() <= 320) {
+			sz = SIZE_ULTRA_TINY;
+			hidebutton_pixmaps = FALSE;
+		} else if(gdk_screen_width() < 800) {
 			sz = SIZE_TINY;
 			hidebutton_pixmaps = FALSE;
-		} else if(gdk_screen_width()<1024) {
+		} else if(gdk_screen_width() < 1024) {
 			sz = SIZE_SMALL;
 			hidebutton_pixmaps = TRUE;
 		} else {
@@ -1076,10 +1148,14 @@ init_user_panels(void)
 		/*load up default applets on the default panel*/
 		load_default_applets1(PANEL_WIDGET(BASEP_WIDGET(panel)->panel));
 
-		if(gdk_screen_height()<600) {
+		/*
+		if(gdk_screen_height() <= 240) {
+			sz = SIZE_ULTRA_TINY;
+			hidebutton_pixmaps = FALSE;
+		} else if(gdk_screen_height() < 600) {
 			sz = SIZE_TINY;
 			hidebutton_pixmaps = FALSE;
-		} else if(gdk_screen_height()<768) {
+		} else if(gdk_screen_height() < 768) {
 			sz = SIZE_SMALL;
 			hidebutton_pixmaps = TRUE;
 		} else {
@@ -1087,7 +1163,7 @@ init_user_panels(void)
 			hidebutton_pixmaps = TRUE;
 		}
 
-		/*panel = aligned_widget_new(ALIGNED_LEFT,
+		panel = aligned_widget_new(ALIGNED_LEFT,
 					   BORDER_RIGHT,
 					   BASEP_EXPLICIT_HIDE,
 					   BASEP_SHOWN,
@@ -1101,8 +1177,13 @@ init_user_panels(void)
 					   TRUE,
 					   NULL);*/
 		panel = foobar_widget_new();
-		FOOBAR_WIDGET (panel)->clock_format = 
-			gnome_config_get_string ("/panel/Config/clock_format=%I:%M:%S %p");
+
+		/* Don't translate the first part of this string */
+		s = gnome_config_get_string (_("/panel/Config/clock_format=%I:%M:%S %p"));
+		if (s != NULL)
+			foobar_widget_set_clock_format (FOOBAR_WIDGET (panel), s);
+		g_free (s);
+
 		panel_setup(panel);
 		gtk_widget_show(panel);	       
 
@@ -1119,7 +1200,7 @@ init_user_panels(void)
 
 	buf = g_string_new(NULL);
 
-	for(num=1;num<=count;num++) {
+	for(num = 1; num <= count; num++) {
 		PanelType type;
 		PanelBackType back_type;
 		int sz;
@@ -1156,11 +1237,12 @@ init_user_panels(void)
 
 		g_string_sprintf(buf,"sz=%d", SIZE_STANDARD);
 		sz=gnome_config_get_int(buf->str);
-		if(sz<0) sz = 0;
+		if(sz < 0)
+			sz = 0;
 
 		/*a hack to allow for old config files to be read correctly*/
 		/*don't update this if new sizes (SIZE_SMALL) are added*/
-		if(sz<4) {
+		if(sz < 4) {
 			switch(sz) {
 			case 0: sz = SIZE_TINY; break;
 			case 1: sz = SIZE_STANDARD; break;
@@ -1289,8 +1371,13 @@ init_user_panels(void)
 		}
 		case FOOBAR_PANEL:
 			panel = foobar_widget_new ();
-			FOOBAR_WIDGET (panel)->clock_format = 
-				gnome_config_get_string ("/panel/Config/clock_format=%I:%M:%S %p");
+
+			/* Don't translate the first part of this string */
+			s = gnome_config_get_string (_("/panel/Config/clock_format=%I:%M:%S %p"));
+			if (s != NULL)
+				foobar_widget_set_clock_format (FOOBAR_WIDGET (panel), s);
+			g_free (s);
+
 			break;
 		default:
 			panel = NULL;
@@ -1316,7 +1403,12 @@ void
 load_up_globals(void)
 {
 	GString *buf;
-	char *tile_def[]={"normal","purple","green","blue"};
+	char *tile_def[] = {
+		"normal",
+		"purple",
+		"green",
+		"blue"
+	};
 	int i;
 	
 	buf = g_string_new(NULL);
@@ -1338,6 +1430,9 @@ load_up_globals(void)
 				      ? "use_large_icons=TRUE"
 				      : "use_large_icons=FALSE");
 
+	global_config.merge_menus =
+		gnome_config_get_bool("merge_menus=TRUE");
+
 	global_config.off_panel_popups =
 		gnome_config_get_bool("off_panel_popups=TRUE");
 		
@@ -1391,6 +1486,7 @@ load_up_globals(void)
 	global_config.tile_when_over = gnome_config_get_bool("tile_when_over=FALSE");
 	global_config.saturate_when_over = gnome_config_get_bool("saturate_when_over=TRUE");
 	global_config.confirm_panel_remove = gnome_config_get_bool("confirm_panel_remove=TRUE");
+	global_config.fast_button_scaling = gnome_config_get_bool("fast_button_scaling=FALSE");
 	
 	g_string_sprintf (buf, "menu_flags=%d", get_default_menu_flags ());
 	global_config.menu_flags = gnome_config_get_int (buf->str);
@@ -1453,6 +1549,8 @@ write_global_config(void)
 			      global_config.hungry_menus);
 	gnome_config_set_bool("use_large_icons",
 			      global_config.use_large_icons);
+	gnome_config_set_bool("merge_menus",
+			      global_config.merge_menus);
 	gnome_config_set_bool("off_panel_popups",
 			      global_config.off_panel_popups);
 	gnome_config_set_bool("disable_animations",
@@ -1479,6 +1577,7 @@ write_global_config(void)
 	gnome_config_set_bool("keys_enabled", global_config.keys_enabled);
 	gnome_config_set_string("menu_key", global_config.menu_key);
 	gnome_config_set_string("run_key", global_config.run_key);
+	gnome_config_set_bool("fast_button_scaling", global_config.fast_button_scaling);
 			     
 	buf = g_string_new(NULL);
 	for(i=0;i<LAST_TILE;i++) {
