@@ -40,6 +40,8 @@ void panel_quit(void);
 void panel_config_sync(void);
 
 void load_up_globals(void);
+/* only to be used on beginning, we don't really want to write globals much */
+void write_global_config(void);
 
 void init_user_applets(void);
 void init_user_panels(void);
